@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2011 by Peter Penz <peter.penz19@gmail.com>             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2011 Peter Penz <peter.penz19@gmail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "kitemlistheaderwidget.h"
 #include "kitemviews/kitemmodelbase.h"
@@ -91,7 +78,7 @@ bool KItemListHeaderWidget::automaticColumnResizing() const
 
 void KItemListHeaderWidget::setColumns(const QList<QByteArray>& roles)
 {
-    foreach (const QByteArray& role, roles) {
+    for (const QByteArray& role : roles) {
         if (!m_columnWidths.contains(role)) {
             m_preferredColumnWidths.remove(role);
         }
@@ -168,7 +155,7 @@ void KItemListHeaderWidget::paint(QPainter* painter, const QStyleOptionGraphicsI
 
     qreal x = -m_offset;
     int orderIndex = 0;
-    foreach (const QByteArray& role, m_columns) {
+    for (const QByteArray& role : qAsConst(m_columns)) {
         const qreal roleWidth = m_columnWidths.value(role);
         const QRectF rect(x, 0, roleWidth, size().height());
         paintRole(painter, role, rect, orderIndex, widget);
@@ -214,18 +201,18 @@ void KItemListHeaderWidget::mouseReleaseEvent(QGraphicsSceneMouseEvent* event)
             const Qt::SortOrder current = (m_model->sortOrder() == Qt::AscendingOrder) ?
                                           Qt::DescendingOrder : Qt::AscendingOrder;
             m_model->setSortOrder(current);
-            emit sortOrderChanged(current, previous);
+            Q_EMIT sortOrderChanged(current, previous);
         } else {
             // Change the sort role and reset to the ascending order
             const QByteArray previous = m_model->sortRole();
             const QByteArray current = m_columns[m_pressedRoleIndex];
             const bool resetSortOrder = m_model->sortOrder() == Qt::DescendingOrder;
             m_model->setSortRole(current, !resetSortOrder);
-            emit sortRoleChanged(current, previous);
+            Q_EMIT sortRoleChanged(current, previous);
 
             if (resetSortOrder) {
                 m_model->setSortOrder(Qt::AscendingOrder);
-                emit sortOrderChanged(Qt::AscendingOrder, Qt::DescendingOrder);
+                Q_EMIT sortOrderChanged(Qt::AscendingOrder, Qt::DescendingOrder);
             }
         }
         break;
@@ -234,7 +221,7 @@ void KItemListHeaderWidget::mouseReleaseEvent(QGraphicsSceneMouseEvent* event)
     case ResizeRoleOperation: {
         const QByteArray pressedRole = m_columns[m_pressedRoleIndex];
         const qreal currentWidth = m_columnWidths.value(pressedRole);
-        emit columnWidthChangeFinished(pressedRole, currentWidth);
+        Q_EMIT columnWidthChangeFinished(pressedRole, currentWidth);
         break;
     }
 
@@ -300,7 +287,7 @@ void KItemListHeaderWidget::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
         m_columnWidths.insert(pressedRole, currentWidth);
         update();
 
-        emit columnWidthChanged(pressedRole, currentWidth, previousWidth);
+        Q_EMIT columnWidthChanged(pressedRole, currentWidth, previousWidth);
         break;
     }
 
@@ -317,7 +304,7 @@ void KItemListHeaderWidget::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
                 const QByteArray role = m_columns[m_movingRole.index];
                 const int previousIndex = m_movingRole.index;
                 m_movingRole.index = targetIndex;
-                emit columnMoved(role, targetIndex, previousIndex);
+                Q_EMIT columnMoved(role, targetIndex, previousIndex);
 
                 m_movingRole.xDec = event->pos().x() - roleXPosition(role);
             }
@@ -342,8 +329,8 @@ void KItemListHeaderWidget::mouseDoubleClickEvent(QGraphicsSceneMouseEvent* even
         setColumnWidth(role, preferredColumnWidth(role));
         qreal currentWidth = columnWidth(role);
 
-        emit columnWidthChanged(role, currentWidth, previousWidth);
-        emit columnWidthChangeFinished(role, currentWidth);
+        Q_EMIT columnWidthChanged(role, currentWidth, previousWidth);
+        Q_EMIT columnWidthChangeFinished(role, currentWidth);
     }
 }
 
@@ -396,7 +383,7 @@ void KItemListHeaderWidget::paintRole(QPainter* painter,
                                       QWidget* widget) const
 {
     // The following code is based on the code from QHeaderView::paintSection().
-    // Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+    // SPDX-FileCopyrightText: 2011 Nokia Corporation and/or its subsidiary(-ies).
     QStyleOptionHeader option;
     option.section = orderIndex;
     option.state = QStyle::State_None | QStyle::State_Raised | QStyle::State_Horizontal;
@@ -481,7 +468,7 @@ int KItemListHeaderWidget::roleIndexAt(const QPointF& pos) const
     int index = -1;
 
     qreal x = -m_offset;
-    foreach (const QByteArray& role, m_columns) {
+    for (const QByteArray& role : qAsConst(m_columns)) {
         ++index;
         x += m_columnWidths.value(role);
         if (pos.x() <= x) {
@@ -562,7 +549,7 @@ int KItemListHeaderWidget::targetOfMovingRole() const
 qreal KItemListHeaderWidget::roleXPosition(const QByteArray& role) const
 {
     qreal x = -m_offset;
-    foreach (const QByteArray& visibleRole, m_columns) {
+    for (const QByteArray& visibleRole : qAsConst(m_columns)) {
         if (visibleRole == role) {
             return x;
         }
